@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.3   2006/11/11
+ * Version: 1.4   2007/04/01
  *
  */
 #include "include.h"
@@ -45,7 +45,9 @@ static void StageArgv0Test(void) {
 		snprintf(buffer, sizeof(buffer) - 1, "Executing /bin/true in permissive mode");
 		ShowPrompt(buffer);
 		wait(&status);
-		ShowResult(WEXITSTATUS(status));
+		errno = WEXITSTATUS(status);
+		ShowResult(errno ? EOF : 0);
+
 		is_enforce = 1; WriteStatus("MAC_FOR_ARGV0=3\n");
 		if (fork() == 0) {
 			execv("/bin/true", argv);
@@ -56,6 +58,18 @@ static void StageArgv0Test(void) {
 		wait(&status);
 		errno = WEXITSTATUS(status);
 		ShowResult(errno ? EOF : 0);
+
+		is_enforce = 0; 
+		if (fork() == 0) {
+			argv[0] = "";
+			execv("/bin/true", argv);
+			_exit(errno);
+		}
+		snprintf(buffer, sizeof(buffer) - 1, "Executing /bin/true in enforce mode");
+		ShowPrompt(buffer);
+		wait(&status);
+		errno = WEXITSTATUS(status);
+		ShowResult(errno ? EOF : 0);
 	}	
 }
 
