@@ -1,22 +1,25 @@
-#! /bin/sh
+#! /bin/bash
 #
 # Initial exception policy generator.
 #
-# Copyright (C) 2005-2006  NTT DATA CORPORATION
+# Copyright (C) 2005-2007  NTT DATA CORPORATION
 #
-# Version: 1.3   2006/11/11
+# Version: 1.3.2   2007/02/14
 #
 # Run this script and save the output as /etc/ccs/exception_policy.txt .
 # You MUST review the content of /etc/ccs/exception_policy.txt
 # because there would be redundant or dangerous entries.
 #
 
+cd ${0%/*}
+export PATH=$PWD:/sbin:/bin:${PATH}
+
 #
 # Make /sbin/modprobe and /sbin/hotplug as initializers, for they can be called by untrusted programs.
 #
 for i in `cat /proc/sys/kernel/modprobe /proc/sys/kernel/hotplug`
 do
-	FILE=`readlink -f $i`
+	FILE=`realpath $i`
 	[ -n "$FILE" -a -f "$FILE" -a -x "$FILE" -a ! -L "$FILE" ] && echo 'initializer '$FILE
 done
 
@@ -97,7 +100,7 @@ grep -qF "Debian" /etc/issue && echo 'file_pattern /tmp/crontab.\?\?\?\?\?\?/cro
 #
 for i in /etc/ld.so.cache /proc/meminfo /proc/sys/kernel/version /etc/localtime /usr/lib/gconv/gconv-modules.cache /usr/lib/locale/locale-archive /usr/share/locale/locale.alias /usr/share/locale/ja/LC_MESSAGES/coreutils.mo /usr/share/locale/ja/LC_MESSAGES/libc.mo
 do
-	FILE=`readlink -f $i`
+	FILE=`realpath $i`
 	[ -n "$FILE" -a -r "$FILE" -a ! -L "$FILE" ] && echo 'allow_read '$FILE
 done
 
@@ -114,14 +117,14 @@ done
 #
 for i in `ldconfig -NXp | grep -F '=>' | awk ' { print $NF } ' | sort | uniq`
 do
-	FILE=`readlink -f $i`
+	FILE=`realpath $i`
 	[ -n "$FILE" -a -s "$FILE" -a ! -L "$FILE" ] && echo 'allow_read '$FILE
 done | sort | uniq
 
 #
 # Mark programs under /etc/init.d/ directory as initializer.
 #
-for FILE in `for i in /etc/init.d/*; do readlink -f $i; done | sort | uniq`
+for FILE in `for i in /etc/init.d/*; do realpath $i; done | sort | uniq`
 do
 	[ -n "$FILE" -a -f "$FILE" -a -x "$FILE" -a ! -L "$FILE" ] && echo "initializer "$FILE
 done
@@ -137,7 +140,7 @@ done
 #
 for FILE in /sbin/getty /sbin/init /sbin/mingetty /sbin/udevd /usr/sbin/anacron /usr/sbin/apache2 /usr/sbin/atd /usr/sbin/cron /usr/sbin/crond /usr/sbin/httpd /usr/sbin/inetd /usr/sbin/logrotate /usr/sbin/smbd /usr/sbin/squid /usr/sbin/sshd /usr/sbin/vsftpd /usr/sbin/xinetd
 do
-  FILE=`readlink -f $FILE 2> /dev/null`
+  FILE=`realpath $FILE 2> /dev/null`
   [ -n "$FILE" -a -f "$FILE" -a -x "$FILE" -a ! -L "$FILE" ] && echo 'initializer '$FILE
 done | sort | uniq
 
